ptexcache_release

Function ptexcache_release 

pub unsafe fn ptexcache_release(cache: *mut PtexCache)
Release a PtexCache Cache will be immediately destroyed and all resources will be released.

Safety

This function must be called with a valid PtexCache pointer.