pub unsafe fn ptextexture_get_path(cache: *const PtexTexture) -> StringExpand description
Get the path for the specified PtexCache.
Safety
This function must be called with a valid PtexTexture pointer.
pub unsafe fn ptextexture_get_path(cache: *const PtexTexture) -> StringGet the path for the specified PtexCache.
This function must be called with a valid PtexTexture pointer.